==> welltested-0.1.1.tar.gz: lib/generators/welltested_save_generator.dart <==
/*
 * Created on Tue Mar 07 2023
 *
 * Copyright (C) 2023 PixelApps - All Rights Reserved
 * The code in this file is Intellectutal Property of PixelApps
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'dart:async';

import 'package:build/src/builder/build_step.dart';
import 'package:analyzer/dart/element/element.dart';
import 'package:source_gen/source_gen.dart';
import 'package:welltested/src/executors/fixer_executor.dart';
import 'package:welltested/src/executors/path_executor.dart';
import 'package:welltested/src/repositories/dart_server_repository.dart';
import 'package:welltested/src/utilities/process.dart';
import 'package:welltested/welltested.dart';

class WelltestedSaveGenerator extends GeneratorForAnnotation<Welltested> {
  @override
  Future<FutureOr<String>> generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) async {
    if (element is! ClassElement) {
      final String friendlyName = element.displayName;
      throw InvalidGenerationSourceError(
        'Generator cannot target `$friendlyName`.',
        todo: 'Remove the [Welltested] annotation from `$friendlyName`.',
      );
    }

    final dartServerExecutor = DartServerExecutor();
    await dartServerExecutor.initialize();

    final PathExecutor pathExecutor = PathExecutor();
    await pathExecutor.init(buildStep);

    final fixerExecutor = FixerExecutor(dartServerExecutor.server);
    return generateWelltestedSource(
      buildStep,
      element,
      save: true,
      fixerExecutor: fixerExecutor,
      dartServerExecutor: dartServerExecutor,
      annotation: annotation,
      pathExecutor: pathExecutor,
    );
  }
}

==> welltested-0.1.3.tar.gz: lib/generators/welltested_save_generator.dart <==
/*
 * Created on Tue Mar 07 2023
 *
 * Copyright (C) 2023 PixelApps - All Rights Reserved
 * The code in this file is Intellectutal Property of PixelApps
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'dart:async';

import 'package:build/src/builder/build_step.dart';
import 'package:analyzer/dart/element/element.dart';
import 'package:source_gen/source_gen.dart';
import 'package:welltested/src/executors/fixer_executor.dart';
import 'package:welltested/src/repositories/path_repository.dart';
import 'package:welltested/src/repositories/dart_server_repository.dart';
import 'package:welltested/src/utilities/process.dart';
import 'package:welltested/welltested.dart';

class WelltestedSaveGenerator extends GeneratorForAnnotation<Welltested> {
  @override
  Future<FutureOr<String>> generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) async {
    if (element is! ClassElement) {
      final String friendlyName = element.displayName;
      throw InvalidGenerationSourceError(
        'Generator cannot target `$friendlyName`.',
        todo: 'Remove the [Welltested] annotation from `$friendlyName`.',
      );
    }

    final dartServerExecutor = DartServerRepository();
    await dartServerExecutor.initialize();

    final PathRepository pathExecutor = PathRepository();
    await pathExecutor.init(buildStep);

    final fixerExecutor = FixerExecutor(dartServerExecutor.server);
    return generateWelltestedSource(
      buildStep,
      element,
      save: true,
      fixerExecutor: fixerExecutor,
      dartServerRepository: dartServerExecutor,
      annotation: annotation,
      pathRepository: pathExecutor,
    );
  }
}
